//
//  AAILIBEventProtocol.h
//  AAILivenessSDK
//
//  Created by advance on 2024/8/2.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

@protocol AAILIBDataHandler <NSObject>

- (void)handleData:(id)data;

@end

@protocol AAILIBDataProvider <NSObject>

- (void)setDataHandler:(id<AAILIBDataHandler>)dataHandler;
- (id<AAILIBDataHandler> _Nullable)dataHandler;

@end

@protocol AAILIBFileStorage<NSObject>

@property(nonatomic, readonly, nullable) dispatch_queue_t storageQueue;
@property(nonatomic, readonly) NSString *fileDirectory;

- (NSString *)fileNameForData:(id)data;
- (void)saveDataToFile:(id)data
            completion:(void (^ _Nullable)(BOOL success))completion;

@end
 

@protocol AAILIBMutiFilesUploadStrategy <NSObject>

@property(nonatomic, readonly) NSString *fileDirPath;

- (BOOL)shouldUploadFiles;

- (NSArray<NSString *> * _Nullable)getPendingFiles;

- (void)uploadFiles:(NSArray<NSString *> *)filePaths
      callbackQueue:(dispatch_queue_t)queue
         completion:(void (^ _Nullable)(BOOL success, NSInteger uploadedCount))completion;
@end


@protocol AAILIBFileUploader <NSObject>

@property(nonatomic, strong, readonly) id<AAILIBMutiFilesUploadStrategy> uploadStrategy;

- (instancetype)initWithUploadStrategy:(id<AAILIBMutiFilesUploadStrategy>)uploadStrategy
                                 queue:(dispatch_queue_t)queue;

- (void)uploadFiles:(void(^ _Nullable)(bool success, NSInteger uploadedCount))complete;

@end

NS_ASSUME_NONNULL_END
