//
//  AAILIBEventCollector.h
//  AAILivenessSDK
//
//  Created by advance on 2024/7/15.
//
#if __has_include(<AAICore/AAILIBEventProtocol.h>)
#import <AAICore/AAILIBEventProtocol.h>
#else
#import "AAILIBEventProtocol.h"
#endif

#if __has_include(<AAICore/AAILIBCXXConstant.h>)
#import <AAICore/AAILIBCXXConstant.h>
#else
#import "AAILIBCXXConstant.h"
#endif

NS_ASSUME_NONNULL_BEGIN
__attribute__((visibility("default")))
@interface AAILIBEventContext:NSObject
@property(nonatomic) NSString *serviceName;
@property(nonatomic) NSString *sdkVersion;
@property(nonatomic, nullable) NSString *sessionId;
@property(nonatomic, nullable) NSString *userId;
@end

__attribute__((visibility("default")))
@interface AAILIBEventProvider: NSObject<AAILIBDataProvider>

@property(nonatomic, readonly) AAILIBEventContext *context;
@property(nonatomic, readonly) dispatch_queue_t trackingQueue;

AAICORE_INIT_UNAVAILABLE()

- (instancetype)initWithTrackingQueue:(dispatch_queue_t)trackingQueue
                              context:(AAILIBEventContext *)context NS_DESIGNATED_INITIALIZER;

- (void)mergePendingTracking:(AAILIBEventProvider *)pendingTracking;

- (NSMutableDictionary *)createUserInfo;

- (NSMutableDictionary *)postProcessEvent:(NSString *)eventName
                                eventInfo:(NSDictionary * _Nullable)eventInfo
                            fullEventInfo:(NSMutableDictionary *)fullEventInfo
                                sessionId:(NSString * _Nullable)sessionId
                                timestamp:(long)timestamp;

- (void)track:(NSString *)eventName
    eventInfo:(NSDictionary * _Nullable)eventInfo;

- (void)track:(NSString *)eventName
    eventInfo:(NSDictionary * _Nullable)eventInfo
   addCommonInfo:(NSDictionary * _Nullable)additionalCommonInfo
     addUserInfo:(NSDictionary * _Nullable)additionalUserInfo;

@end

__attribute__((visibility("default")))
@interface AAILIBEventStorage : NSObject<AAILIBFileStorage>

AAICORE_INIT_UNAVAILABLE()

- (instancetype)initWithFileDirPath:(NSString *)fileDirPath
                       storageQueue:(nullable dispatch_queue_t)storageQueue NS_DESIGNATED_INITIALIZER;
@end

__attribute__((visibility("default")))
@interface AAILIBEventManager: NSObject<AAILIBDataHandler>

@property(nonatomic, readonly) id<AAILIBDataProvider> dataProvider;
@property(nonatomic, readonly) id<AAILIBFileStorage> storage;
@property(nonatomic, readonly) id<AAILIBFileUploader> uploader;

AAICORE_INIT_UNAVAILABLE()

- (instancetype)initWithDataProvider:(id<AAILIBDataProvider>)dataProvider
                             storage:(id<AAILIBFileStorage>)storage
                            uploader:(id<AAILIBFileUploader>)uploader NS_DESIGNATED_INITIALIZER;

@end

NS_ASSUME_NONNULL_END

